@@ -229,6 +229,18 @@ class Post(object):
         else:
             assert False, "Unknown type for %r" % self
 
+    @property
+    def year(self):
+        return self.date.year
+
+    @property
+    def month(self):
+        return self.date.month
+
+    @property
+    def day(self):
+        return self.date.day
+
     def formatted_date(self):
         if isinstance(self.date, datetime.datetime):
             return self.date.strftime('%Y-%m-%d %H:%M')
