@@ -5,11 +5,10 @@ import codecs
 from shutil import copy
 
 import weblog
-from template import jinja_environment
+from template import environment
 from html_full_url import html_full_url
 from post import Post, PostError
 from load import load_post_list, load_configuration
-from listing import generate_index_listing
 
 def generate_post_html(post_list, output_dir, post_tmpl, params):
     for post in post_list:
@@ -58,7 +57,7 @@ def command_publish(args, options):
     if not os.path.exists(output_dir):
         os.mkdir(output_dir)
 
-    env = jinja_environment(source_dir)
+    env = environment(source_dir)
 
     try:
         post_list = list(reversed(sorted(load_post_list(source_dir))))
@@ -74,14 +73,18 @@ def command_publish(args, options):
                       html_header=config.get('html_header'),
                       html_footer=config.get('html_footer'))
 
-        # generate the main index page
-        logging.debug('Generating HTML listings')
+        logging.debug('Generating archives page')
+        archives_template = env.get_template('archives.html.tmpl')
+        open(os.path.join(output_dir, 'archives.html'), 'w').\
+                write(archives_template.render(posts=post_list,
+                                               **params))
+
+        logging.debug('Generating main page')
         index_template = env.get_template('index.html.tmpl')
-        generate_index_listing(config['post_per_page'],
-                               output_dir,
-                               index_template,
-                               post_list,
-                               params)
+        open(os.path.join(output_dir, 'index.html'), 'w').\
+                write(index_template.render(posts=post_list,
+                                            config=config,
+                                            **params))
 
         logging.debug('Generating HTML posts files')
         post_tmpl = env.get_template('post.html.tmpl')
